global DataDir OutDir

% Load and/or create XMAT, a matrix that contains the data.
%
% XMAT must contain one row of data for each alternative in each choice situation for each person.
% The rows are grouped by person, and by choice situations faced by each person.
% The number of rows in XMAT must be NROWS, specified above.
% The columns in XMAT are variable that describe the alternative.
% 
% The *dsm* column of XMAT identifies the person who faced this alternative. 
% The people must be numbered sequentially from 1 to NP, in ascending order.
% All alternatives for a given person must be grouped together.
% The *cs* column of XMAT identifies the choice situation. The choice
% situations must be numbered sequentially from 1 to NCS.
% All alternatives for a given choice situation must be grouped together.
% The *choice* column of XMAT identifies the chosen alternatives (1 for
% chosen, 0 for not). One and only one alternative must be chosen for each
% choice situation.
% The *alt* column of XMAT identifies the alternatives on offer in each 
% choice situation. Code assumes options go from 1,2,...,J
% The *mar* column of XMAT identifies the market the decision-maker belongs 
% belongs. Code assumes markets go from 1,2,...M
% The remaining columns of XMAT can be any variables.

dsm=2;
dcs=1;
choice=5;
alt=4;
mar=3;

% MODEL SPECIFICATION

% RANDOM COEFFICIENTS
% List the variables in XMAT that enter the model with random coefficients and
% give the distribution for the coefficient of each variable.
% IDV contains one row for each random coefficient and two columns.
% The *first* column gives the number of a variable in XMAT that has a random coefficient, 
% and the *second* column specifies the distribution of the coefficient for that variable.
% The distributions can be 
% 1. normal: N(b,w^2) where mean b and standard deviation w are estimated.
% 2. lognormal: coefficient is exp(beta) where beta~N(b,w^2) with b and w estimated
% 3. truncated normal, with the share below zero massed at zero: max(0,beta) where 
%                      beta~N(b,w^2) with b and w estimated.
% 4. S_B: exp(beta)/(1+exp(beta))  where beta~N(b,w^2) with b and w estimated.
% 5. normal with zero mean (for error components): N(0,w^2) where w is estimated.
% 6. triangular: b+w*t where t is triangular between -1 and 1 and mean b and spread w are estimated.
% If no random coefficients, put IDV=[];
% Notes:
% The lognormal, truncated normal, and S_B distributions give positive
% coefficients only. If you want a variable to have only negative coefficients, 
% create the negative of the variable (in the specification of XMAT above).
% The S_B distribution gives coefficients between 0 and 1. If you want
% coefficients to be between 0 and k, then multiply the variable by k (in the specification 
% of XMAT above), since b*k*x for b~(0-1) is the same as b*x for b~(0-k).
% If no random coefficients, put IDV=[];
 
 IDV=[  6 2 ;...
        7 1 ;...
        8 1 ;...
        93 5 ;...
        26 5];
    
NV=size(IDV,1); %Number of random coefficients. Do not change this line.

% Give a name to each of the explanatory variables in IDV. They can 
% have up to ten characters including spaces. Put the names in single quotes and separate 
% the quotes with semicolons. If IDV=[], then set NAMES=[];
NAMES={'price';'own_ad';'comp_ad';'nutrientscore';'walkers'}; 


% Starting values
% Specify the starting values for b and w for each random coeffient.
% B contains the first parameter, b, for each random coefficient.  
% It is a column vector with the same length as IDV. For distribution 5 (normal with zero mean),
% put 0 for the starting value for the mean. The code will keep it at 0.

B=[  0.2525;  0.0380; -0.1184;  0.0000;  0.0000];

corrc=0;
W=[ 0.1344; 0.0264; 0.1157; 0.0026; 1.2226];

% FIXED COEFFICIENTS
% List the variables in XMAT that enter with fixed coefficients.
% Put semicolons between the numbers.
% If no fixed coefficients, put IDF=[];

IDF=[(11:25) (27:92) 94 95]';

NF=size(IDF,1); %Number of fixed coefficients. Do not change this line.

% Give a name to each of the variables in IDF.
NAMESF={'size';'size_sq';'price_own_stock';'health_cost_stock';'pringles';'walk_reg';'walk_sen';'walk_dor';'walk_oth';'kp';'gw';'asda';'tesco';'outside1';'outside2';'pringles_2';'pringles_3';'pringles_4';'pringles_5';'pringles_6';'pringles_7';'pringles_8';'pringles_9';'pringles_10';'pringles_11';'pringles_12';'pringles_13';'pringles_14';'pringles_15';'pringles_16';'pringles_17';'walk_reg_2';'walk_reg_3';'walk_reg_4';'walk_reg_5';'walk_reg_6';'walk_reg_7';'walk_reg_8';'walk_reg_9';'walk_reg_10';'walk_reg_11';'walk_reg_12';'walk_reg_13';'walk_reg_14';'walk_reg_15';'walk_reg_16';'walk_reg_17';'othbrds_2';'othbrds_3';'othbrds_4';'othbrds_5';'othbrds_6';'othbrds_7';'othbrds_8';'othbrds_9';'othbrds_10';'othbrds_11';'othbrds_12';'othbrds_13';'othbrds_14';'othbrds_15';'othbrds_16';'othbrds_17';'outside1_2';'outside1_3';'outside1_4';'outside1_5';'outside1_6';'outside1_7';'outside1_8';'outside1_9';'outside1_10';'outside1_11';'outside1_12';'outside1_13';'outside1_14';'outside1_15';'outside1_16';'outside1_17';'outside2_r1';'outside2_r2';'CF_adv';'CF_price'}; 

% Starting values.
% Specify the starting values for the fixed coefficients F.
% F must have the same length as IDF and have one column.
% Put semicolons between the elements (so F will be a column vector.)
F=[0.0202; -0.0170; -0.0563; -0.0060; -1.8418;  0.3962; -1.6145; -1.6377;  0.3917;  0.0335; -2.3539; -1.4080; -1.2958;  3.5957;  1.8465; -0.1756;  1.0192;  0.3453;  0.7887;  0.8665;  1.0106;  0.4359;  0.7966;  -0.5224;   0.6034;  -0.2555;   0.9641;   0.5450;  -0.2351;   0.0706;  -0.1949; -0.5338; -0.6723; -1.0078; -0.6450; -0.1770; -0.6873; -0.4047; -0.3876;  -1.0298;  -0.3455;  -0.8654;  -1.0279;  -0.7236;  -0.8775;  -0.5183;  -0.5568; -0.5551; -0.5445; -0.4057; -0.6627; -0.3072; -1.1001; -0.8769; -0.5821; -0.8982; -0.2976; -0.7574; -0.6497; -0.4119; -0.7672; -0.4528; -0.6091; -0.4409; -0.0764; -0.2966; -0.3135; -0.0365; -0.7524; -0.3971; -0.3801;  -0.7362;  -0.2082;  -0.6189;  -0.4508;  -0.1253;  -0.5191;  -0.2019;  -0.4280;  -0.1058;0.2465;0;0];

% *PV* is column containing price in XMAT
% *PIV* is column containing price interactions in XMAT
PV=6;
PVI=[13 1];
% File to hold coefficient estimates
CoefFile=fullfile(OutDir,[OutString,'coeffs.mat']);
BootFile=fullfile(OutDir,[OutString,'bootstrapcoeffs.mat']);

%File to hold variables from equilibrium
EqFile=fullfile(OutDir,[OutString,'equilibrium.mat']);

% Set asymmetry=0 if choice sets are the same in each choice situation, 1
% otherwise
% Set pricedata=0 for mean market price to be used as price in market
% elasticity formula
% Set pricedata=1 for prices to be uploaded
asymmetry=0;
pricedata=0;

% OutsideOptionIn set to 1 if outside option exits, set to  0 otherwise
% *OProd* is firm code denoting the outside option(s)
% *OBrand* is brand code denoting the outside option(s)
% *OFirm* is firm code denoting the outside option(s)
OutsideOptionIn=1;
OProd=[27 28]';
OBrand=[11 12]';
OFirm=[8 9]';

% PriceSim=1 if simulation variable is price; 0 for other variable
% behavioural=1 if baseline 'perceived' and 'true' utility vary
% In this case SV=PV and SVI=PVI; otherwise
% *SV*  refers to variable subject to simulation
% *SVI* refers to interactions involving simulation variable 
%   First column identified variable and second power
% *SV2* and *SVI2* are for a second simulated variable
% Default simulation transformation is as:
%   PostSimVar = CC1 + CC2*PreSimVar
% For tax levied on product characteristic set
%   Excise=1    (CC1*Factor + PreSimVar) or 
%   Advalorem=1 ((1+CC2*Factor)*PreSimVar)
%   *Factor* indexes product characteristics
% FixedPriceIn=1 if any products' price is fixed during simulations; 0
% otherwise
% FProd refers to products with fixed price during simulation (other than
% outside option)
PriceSim=0;
behavioural=1;
SV=7;
SVI=[13 1; ...
     14 1];
SV2=8;
SVI2=[];
CC1=0;
CC2=0;
Factor=[];
FixedPriceIn=0;
FProd=[];

% PriceDataFile refers to name of file containing price data
%   One observation per product, variables 2 onwards are market price
%   Sorted by product
% FirmDataFile refers to ownership matrix
%   One observation per product, variables - product,firm,dummies
PriceDataFile=fullfile(DataDir,[BaseString,'_price_data.raw']);
FirmDataFile=fullfile(DataDir,[BaseString,'_firm_data.raw']);
AdEffectData=fullfile(DataDir,[BaseString,'_ad_effects_cf.raw']);

% DemandOut refers to demand curve output
DemandOutPre=fullfile(OutDir,[OutString,'demand_presim.raw']);
DemandOutNR=fullfile(OutDir,[OutString,'demand_simnr.raw']);
DemandOutNE=fullfile(OutDir,[OutString,'demand_simne.raw']);

% MElasOut refers to market elasticity output
% DElasOut refers to disaggregate elasticity output
MElasOut=fullfile(OutDir,[OutString,'melas.raw']);
MSElasOut=fullfile(OutDir,[OutString,'mSelas.raw']);
DElasOut=fullfile(OutDir,[OutString,'delas.raw']);
AdFiniteOut=fullfile(OutDir,[OutString,'adfinite.raw']);

% ProductOut refers to product level output
% BrandOut refers to product level output
% SimOut refers to simulation output
ProductOut=fullfile(OutDir,[OutString,'products.raw']);
BrandOut=fullfile(OutDir,[OutString,'brands.raw']);
DisOut=fullfile(OutDir,[OutString,'disshare.raw']);
DisSimOut=fullfile(OutDir,[OutString,'dissimshare.raw']);
WelfareOut=fullfile(OutDir,[OutString,'welfare.raw']);

% Type of draws to use in simulation
% 1=pseudo-random draws
% 2=standard Halton draws
% 3=shifted and shuffled Halton draws
% 4=modified Latin hypercube sampling, shifted and shuffled 
% 5=create your own draws or load draws from file
DRAWTYPE=4;

% Number of draws from to use per person in simulation.
NDRAWS=100;

% Set seed for the random number generator.
SEED1 = 12239; 

% If DRAWTYPE=5, then create or load the draws here.
% Create or load a data array, called DR, with dimensions NV x NP x NDRAWS.
% where element DR(i,j,k) is the k-th draw of random coefficient i for person j 
% Put your statements between "if DRAWTYPE==5" and "end".
% 
% If you created DR in a previous matlab session and saved it
% with "save mydraws DR" then put "load('mydraws.mat')" here. The structure
% mydraws will contain the array DR.
% Note: If you want to use the draws that were saved to PUTDR below in a 
% previous run, see the ReadMe.txt file for instructions.

if DRAWTYPE==5
   load('mydraws.mat');
end

% Memory use
% Give the number of draws that you want held in memory at one time.
% This number must be evenly divisible into the number of draws.
% That is NDRAWS./NMEM must be a positive integer.
% To hold all draws in memory at once, set NMEM=NDRAWS.
% A larger value of NMEM requires fewer reads from disc but 
% uses more memory which can slow-down the calculations and increases 
% the chance of running out of memory.
% If DRAWTYPE=5, then you must set NMEM=NDRAWS
NMEM=100;

% If all the draws are NOT held in memory at one time (that is, if NMEM<NDRAWS), 
% then give the filename (including full path if not in the working directory)
% that you want the draws to be temporarily saved to while the code is running.
% If all draws are held in memory at one time (that is, if NMEM=NDRAWS),
% then this file will not be created. So, if NMEM=NDRAWS, you can set PUTDR=''; 
% or give a file name, whichever you find more convenient, since the name won't be used.
PUTDR=fullfile(OutDir,[OutString,'draws']);

% WEIGHTS. 
% Do you want to apply weights to the people? 
% Set WANTWGT=1 if you want to apply weights; otherwise set WANTWGT=0;
WANTWGT=0;

% If WANTWGT=1, identify the variable in XMAT that contains the weights.
% This variable can vary over people but must be the same for all rows of
% data for each person. Weights cannot vary over choice situations for
% each person or over alternatives for each choice situation -- only over people.
% The code normalizes the weights such that the sum 
% of weights over people is to equal NP (to assure that standard errors 
% are correctly calculated.) If WANTWGT=0, set IDWGT=[];
IDWGT=[];

% OPTIMIZATION 
% Maximum number of iterations for the optimization routine.
% The code will abort after ITERMAX iterations, even if convergence has
% not been achieved. The default is 400, which is used when MAXITERS=[];
MAXITERS=1000;

% Convergence criterion based on the maximum change in parameters that is considered
% to represent convergence. If all the parameters change by less than PARAMTOL 
% from one iteration to the next, then the code considers convergence to have been
% achieved. The default is 0.000001, which is used when PARAMTOL=[];
PARAMTOL=0.000001;

% Convergence criterion based on change in the log-likelihood that is
% considered to represent convergence. If the log-likelihood value changes
% less than LLTOL from one iteration to the next, then the optimization routine
% considers convergence to have been achieved. The default is 0.000001,
% which is used when LLTOL=[];
LLTOL=[];
