% Array of draws has dimension NMEMxNPxNV.


function dr=makedraws
 
global IDV NV NP DRAWTYPE NMEM NTAKES NDRAWS PUTDR

if NTAKES>1
  fid=fopen(PUTDR,'w'); 
  dr=[];
else
  dr=zeros(NMEM,NP,NV);
end


if DRAWTYPE == 1              %Random draws
  if NTAKES == 1              %Create all at once
      for j=1:NV
        if IDV(j,2) ~=6              %Based on normal: not triangular
           dr(:,:,j)=randn(NMEM,NP);
        else                         %Triangular
           draws=rand(NMEM,NP);
           dr(:,:,j)=(sqrt(2.*draws)-1) .* (draws<=.5) + (1-sqrt(2.*(1-draws))) .* (draws >.5);
        end
     end
  else                       %Create and write NMEM draws for each person
                             %   since draws are to be read as NMEMxNP for each NV 
     for j=1:NV
         for p=1:NP
             for k=1:NTAKES
                if IDV(j,2)~=6
                   draws=randn(NMEM,1);
                else
                   draws=rand(NMEM,1);
                   draws=(sqrt(2.*draws)-1) .* (draws<=.5) + (1-sqrt(2.*(1-draws))) .* (draws >.5);
                end
                fwrite(fid,draws,'double');
             end
         end
     end
   end
end

if DRAWTYPE == 2 | DRAWTYPE == 3   % Halton draws - Must create for all people together
   h=primes(100);                  % Row vector of all primes up to 100               
   k=1;
   while size(h,2) < NV  % Skip if there are less than 25 random coeffs
       h=primes(k.*100);
       k=k+1;
   end
   h=h(1,1:NV); %Take first primes corresponding to number of random ceoffs
   for j=1:NV   %Cycle through random coeffs
       hh=h(1,j);   %Select prime correspond to current random coeff
       draws=[0];   %Set starting of sequence to zero
       test=0;
       b=1;
   % Consider Halton sequence of 3:
   % Sequence is s{t+1} = (s{t},s{t}+1/3^t,s{t}+2/3^t)
   % s{0} = 0
   % s{1} = (0,1/3,2/3)
   %    The 1st iteration creates 1/3, and the 2nd 2/3
   % s{2} = (0      , 1/3      , 2/3
   %         0+1/3^2, 1/3+1/3^2, 2/3+1/3^2
   %         0+2/3^2, 2/3+2/3^2, 2/3+2/3^2)
   %    The 3rd iteration creates the 2nd line, and the 4th the 3rd line
       
       while test == 0  
            drawsold=draws; %Save old values
            for m=1:(hh-1); %Cycle up to prime-1
                dd=m./(hh.^b);  %Generate m/prime^t
                draws=[draws ; drawsold + dd]; %Add new values to sequence
                test=size(draws,1) >= ((NP.*NDRAWS) + 10);
                %Stop if number of draws exceeds NP.*NDRAWS+10
                if test == 1
                   break
                end
            end
            b=b+1;    
       end
       draws=draws(11:(NP.*NDRAWS)+10,1);   %Discard first 10 in sequences (and all those number beyond NP.*NDRAWS+10)
       if DRAWTYPE == 3                          %Make draws random   
            draws=draws+rand(1,1);               %Add random number to entire sequence
            draws=draws-floor(draws);            %Subtract 1 if element of modified sequences exceeds 1   
            draws=reshape(draws,NDRAWS,NP);
            for n=1:NP                           %Randomly shuffle for each person separately
               rr=rand(NDRAWS,1);
               [rr rrid]=sort(rr);
               draws(:,n)=draws(rrid,n);
            end;
            draws=reshape(draws,NP.*NDRAWS,1);  
       end
       if IDV(j,2)~=6
           draws=-sqrt(2).*erfcinv(2.*draws);  %Take inverse cum normal
       else
           draws=(sqrt(2.*draws)-1) .* (draws<=.5) + (1-sqrt(2.*(1-draws))) .* (draws >.5); %For triangular dist 
       end
       if NTAKES == 1
           dr(:,:,j)=reshape(draws,NDRAWS,NP);
       else
           fwrite(fid,draws,'double');
       end
    end
end

if DRAWTYPE == 4   % MLHS

  h=0:(NDRAWS-1);
  h=h'./NDRAWS;    %Evenly spaced elements from 0 to 1-1/NRAWS
  for j=1:NV
    for n=1:NP          %Shift: Different shift for each person
       draws=h+rand(1,1)./NDRAWS;  %Add random value between 0 and 1/NDRAWS to each element  
       rr=rand(NDRAWS,1);
       [rr rrid]=sort(rr);
       draws=draws(rrid,1);          %Shuffle
       if IDV(j,2)~=6
           draws=-sqrt(2).*erfcinv(2.*draws);  %Take inverse cum normal
       else
           draws=(sqrt(2.*draws)-1) .* (draws<=.5) + (1-sqrt(2.*(1-draws))) .* (draws >.5); 
       end
       if NTAKES == 1
         dr(:,n,j)=draws;
       else
         fwrite(fid,draws,'double');
       end
     end
   end
end

if NTAKES>1
  fclose(fid);
end