**************************************************************************
**Tables for data section
**************************************************************************

u "$Data/FoodIn_allweeks.dta",clear

merge m:1 week product using "$Data/FoodIn_characteristics.dta",keepusing(price size)
drop _m

egen sum = sum(size),by(product)
egen sum2 = sum(size)
gen share = (sum/sum2)*100

lab def prod_in_full 1 "Pringles:150-300g"  2  "Pringles:300g+" 3 "Walkers Regular:150-300g" 4  "Walkers Regular:300g+" 5  "Walkers Sensations:150-300g" 6 "Walkers Sensations:300g+" 7 "Walkers Doritos:150-300g" 8 "Walkers Doritos:300g+" 9 "Walkers Other:<150g"  10 "Walkers Other:150-300g"  11 "Walkers Other:300g+" 12 "KP:<150g"  13 "KP:150-300g"  14 "KP:300g+" 15 "Golden Wonder:<150g"  16 "Golden Wonder:150-300g"  17 "Golden Wonder:300g+" 18 "Asda:<150g"  19 "Asda:150-300g" 20 "Asda:300g+" 21 "Tesco:<150g"  22 "Tesco:150-300g" 23 "Tesco:300g+" 24 "Other:<150g"  25 "Other:150-300g" 26 "Other:300g+" 199 "Outside option" 999 "Outside option 2"
lab val product prod_in_full

**Table 4.2
tabout product using "$T/data_product_in.tex" if product<199, replace sum bt ptotal(none) format(2p 2) cells(mean share mean price) style(tex) h1(nil) h2(nil) h3(Products & Quantity Share & Price (\pounds) \\)

u "$Data/FOTG_allweeks.dta",clear

merge m:1 week product using "$Data/FOTG_characteristics.dta",keepusing(price size)
drop _m

egen sum = sum(size),by(product)
egen sum2 = sum(size)
gen share = (sum/sum2)*100

lab def prod_out_full 101 "Walkers Reg:34.5g" 102 "Walkers Reg:50g" 103 "Walkers Sensations:40g" 104 "Walkers Doritos:40g" 105 "Walkers Other:<30g" 106 "Walkers Other:30g+" 107 "KP:50g" 108 "Golden Wonder:<40g" 109 "Golden Wonder:40g+" 110 "Other:<40g" 111 "Other:40g+" 199 "Outside option" 999 "Outside option 2"
lab val product prod_out_full

**Table 4.2
tabout product using "$T/data_product_out.tex" if product<999, replace sum bt ptotal(none) format(2p 2) cells(mean share mean price) style(tex) h1(nil) h2(nil) h3(Products & Quantity Share & Price (\pounds) \\)

u "$Data/FoodIn_characteristics.dta",clear

gen     brand = 1  if product==1 |product==2
replace brand = 2  if product==3 |product==4
replace brand = 3  if product==5 |product==6
replace brand = 4  if product==7 |product==8
replace brand = 5  if product==9|product==10|product==11
replace brand = 6  if product==12|product==13|product==14
replace brand = 7  if product==15|product==16|product==17
replace brand = 8  if product==18|product==19|product==20
replace brand = 9  if product==21|product==22|product==23
replace brand = 10 if product==24|product==25|product==26
replace brand = 11 if product==27
replace brand = 12 if product==28

lab def brand_d 1 "Pringles" 2 "Walkers Regular" 3 "Walkers Sensations" 4 "Walkers Doritos" 5 "Walkers Other" 6 "KP" 7 "Golden Wonder" 8 "Asda" 9 "Tesco" 10 "Other" 11 "Outside Option" 12 "Outside option 2"
lab val brand brand_d

**Table 4.3
tabout brand using "$T/nutrientsummary.tex", replace sum bt ptotal(none) format(0 0 2 2) cells(mean health_cost mean energy_kj mean saturates mean sodium) style(tex) h1(nil) h2(& Nutrient & Energy & Saturated fat & Sodium \\) h3(& score & (kj per 100g) & (g per 100g) & (g per 100g) \\)

u "$Data/Foodin_allweeks.dta",clear

bysort hhno group: gen hh = 1 if _n==1
gen purchase_fi = 1

collapse (sum) purchase_fi hh,by(group)

sa "$Data/fi_hh.dta",replace

u "$Data/FOTG_allweeks.dta",clear

bysort hhno indvno group: gen ind = 1 if _n==1
gen purchase_fotg = 1

collapse (sum) purchase_fotg ind,by(group)

merge 1:1 group using "$Data/fi_hh.dta"
drop _m

gen     hhtype = 1 if group<6
replace hhtype = 2 if group==6
replace hhtype = 3 if group>6 & group<12
replace hhtype = 4 if group==12

lab def hhtype 1 "Non-pensioner household, no kids" 2 "Pensioner household" 3 "Household with kids" 4 "Person below 18"
lab val hhtype hhtype

gen     inc = 1 if group==1|group==7
replace inc = 2 if group==4|group==10
replace inc = 3 if group==2|group==8
replace inc = 4 if group==3|group==5|group==9|group==11
replace inc = 5 if group==6|group==12

lab def inc 1 "Income pp>household type 66p" 2 "Income pp>household type 33p" 3 "Income pp in [household type 33p,household type 66p]" 4 "Income pp<household type 33p" 5 "Any income"
lab val inc inc

gen     skill = 1 if group==1|group==2|group==3|group==7|group==8|group==9
replace skill = 2 if group==4|group==5|group==10|group==11
replace skill = 3 if group==6|group==12
lab def skill 1 "High education" 2 "Low education" 3 "Any education"
lab val skill skill

rename group         Type
rename hhtype        Composition
rename inc           Income
rename skill         Skill
rename hh            Households
rename ind           Individuals
rename purchase_fi   Food_in_purchase_occasions
rename purchase_fotg FOTG_purchase_occasions

lab def Type 1 "No kids, high income, high education" 2   "No kids, med income, high education" 3   "No kids, low income, high education" 4   "No kids, high-medium income, low education" 5   "No kids, low income, low education" 6   "Pensioners" 7   "Kids, high income, high education" 8   "Kids, med income, high education" 9   "Kids, low income, high education" 10  "Kids, high-medium income, low education" 11  "Kids, low income, low education" 12  "Kid purchase"
lab val Type Type

**Table 4.4
tabout Type using "$T/data_hhs.tex", replace sum bt ptotal(none) format(0) cells(mean Households mean Individuals mean Food_in_purchase_occasions mean FOTG_purchase_occasions) style(tex) h1(nil) h2(nil) h3( & & & purchase occasions & purchase occasions \\)


**Advertising description
**Section 4.1.1
do "$Progs/AdDataSection.do"

