
**************************************************************************
**Price elasticities
**************************************************************************

insheet using "$In_in/fimelas.raw",clear

rename v1 market
rename v2 altop
rename v3 altpr
rename v4 elas
drop v5

lab var market       "Index of market"
lab var altop        "Share product"
lab var altpr        "Price product"
lab var elas         "Price elasticity"

collapse (mean) elas,by(altop altpr)

reshape wide elas,i(altop) j(altpr)

rename elas1  Pringles_150_300g
rename elas2  Pringles_300g
rename elas3  Walkers_Reg_150_300g
rename elas4  Walkers_Reg_300g
rename elas5  Walkers_Sens_150_300g
rename elas6  Walkers_Sens_300g
rename elas7  Walkers_Dor_150_300g
rename elas8  Walkers_Dor_300g
rename elas9  Walkers_Oth_150g
rename elas10 Walkers_Oth_150_300g
rename elas11 Walkers_Oth_300g
rename elas12 KP_150g
rename elas13 KP_150_300g
rename elas14 KP_300g
rename elas15 GW_150g
rename elas16 GW_150_300g
rename elas17 GW_300g
rename elas18 Asda_150g
rename elas19 Asda_150_300g
rename elas20 Asda_300g
rename elas21 Tesco_150g
rename elas22 Tesco_150_300g
rename elas23 Tesco_300g
rename elas24 Other_150g
rename elas25 Other_150_300g
rename elas26 Other_300g
rename elas27 Outside_option_1
rename elas28 Outside_option_2

sa "$Out/fimelas.dta",replace


**************************************************************************
**Marginal costs
**************************************************************************

*******************
***FOOD IN
*******************

insheet using "$In_in/fiproducts.raw",clear

rename v1 market
rename v2 product
rename v3 brand
rename v4 share
rename v5 price
rename v6 costs
rename v7 mean_trs_ad
drop v8

gen margin = (price-cost)/price

lab var market       "Index of market"
lab var product      "Product"
lab var brand        "Brand"
lab var share        "Predicted market share"
lab var price        "Price"
lab var costs        "Imputed marginal cost"
lab var mean_trs_ad  "Mean transformed ad"
lab var margin       "(Price-cost)/price"

sa "$Out/fi_products.dta",replace

*******************
***FOOD ON THE GO
*******************

insheet using "$In_out/fotgproducts.raw",clear

rename v1 market
rename v2 product
rename v3 brand
rename v4 share
rename v5 price
rename v6 costs
rename v7 mean_trs_ad
drop v8

gen margin = (price-cost)/price

lab var market       "Index of market"
lab var product      "Product"
lab var brand        "Brand"
lab var share        "Predicted market share"
lab var price        "Price"
lab var costs        "Imputed marginal cost"
lab var mean_trs_ad  "Mean transformed ad"
lab var margin       "(Price-cost)/price"

sa "$Out/fotg_products.dta",replace

*******************
***TOGETHER
*******************

u "$Out/fotg_products.dta",clear

replace product = product+100

append using "$Out/fi_products.dta"

replace product = 112 if product==27

collapse (sum) costs price margin,by(product brand market)

sa "$Out/products.dta",replace

**************************************************************************
**Simulations
**************************************************************************

*******************
***FOOD IN
*******************

insheet using "$In_in/fisimulations.raw",clear

rename v1  market
rename v2  product
drop   v3
rename v4  costs
rename v5  price_pre
rename v6  price_post
rename v7  share_pre
rename v8  share_post_nr
rename v9  share_post_r
drop v10
drop v11

lab var market        "Index of market"
lab var product       "Product"
lab var costs         "Imputed marginal cost"
lab var price_pre     "Price pre ban"
lab var price_post    "Price post ban (no firm response)"
lab var share_pre     "Share pre ban"
lab var share_post_nr "Share post ban (no firm response)"
lab var share_post_r  "Share post ban (firm response)"

gen     brand = 1  if product==1 |product==2
replace brand = 2  if product==3 |product==4
replace brand = 3  if product==5 |product==6
replace brand = 4  if product==7 |product==8
replace brand = 5  if product==9|product==10|product==11
replace brand = 6  if product==12|product==13|product==14
replace brand = 7  if product==15|product==16|product==17
replace brand = 8  if product==18|product==19|product==20
replace brand = 9  if product==21|product==22|product==23
replace brand = 10 if product==24|product==25|product==26
replace brand = 11 if product==27
replace brand = 12 if product==28

foreach v in _pre _post_nr _post_r {
    gen purchase`v' = share`v'*($Insize/12)
}

foreach v in share_pre share_post_nr share_post_r {
    replace `v' = `v'*100
}

merge m:1 brand market using "$Data/ad_flow.dta"
drop if _m==2
drop _m

rename own_flow advertising_flow

merge 1:1 market product using "$Data/fi_sizecost.dta"
drop if _m==2
drop _m
replace size          = 0 if size==.
replace health_cost   = 0 if health_cost==.
replace vol_energy_kj = 0 if vol_energy_kj==.
replace vol_saturates = 0 if vol_saturates==.
replace vol_salt      = 0 if vol_salt==.

gen exp_pre     = price_pre *purchase_pre
gen exp_post_nr = price_pre *purchase_post_nr
gen exp_post_r  = price_post*purchase_post_r

gen q_pre     = purchase_pre    *size
gen q_post_nr = purchase_post_nr*size
gen q_post_r  = purchase_post_r *size

gen gprof_pre     = (price_pre -costs)*purchase_pre
gen gprof_post_nr = (price_pre -costs)*purchase_post_nr
gen gprof_post_r  = (price_post-costs)*purchase_post_r

gen en_pre     = purchase_pre    *vol_energy_kj
gen en_post_nr = purchase_post_nr*vol_energy_kj
gen en_post_r  = purchase_post_r *vol_energy_kj

gen sf_pre     = purchase_pre    *vol_saturates
gen sf_post_nr = purchase_post_nr*vol_saturates
gen sf_post_r  = purchase_post_r *vol_saturates

gen st_pre     = purchase_pre    *vol_salt
gen st_post_nr = purchase_post_nr*vol_salt
gen st_post_r  = purchase_post_r *vol_salt

sa "$Out/fi_simulations.dta",replace

u "$Out/fi_simulations.dta",clear

gen     firm = 1 if brand==1
replace firm = 2 if brand==2 | brand==3 | brand==4 | brand==5
replace firm = 3 if brand==6
replace firm = 4 if brand==7
replace firm = 5 if brand==8
replace firm = 6 if brand==9
replace firm = 7 if brand==10
drop if brand==11|brand==12

lab def firm 1 "Pringles" 2 "Walkers" 3 "KP" 4 "Golden Wonder" 5 "Asda" 6 "Tesco" 7 "Other"
lab val firm firm

bysort brand market: replace advertising_flow = . if _n!=1

collapse (sum) advertising_flow gprof_pre gprof_post_nr gprof_post_r q_pre q_post_nr q_post_r (mean) price_pre price_post,by(firm market)

sa "$Out/fi_firmsimulations.dta",replace

**Effect of ban on prices

u "$Out/fi_simulations.dta",clear

keep market product brand price_pre price_post

collapse (mean) price_pre price_post,by(product brand)

keep if product==1|product==2|product==3|product==4|product==12|product==13|product==14

gen     size = 1 if product==12
replace size = 2 if product==1|product==3|product==13
replace size = 3 if product==2|product==4|product==14
drop product

reshape wide price_pre price_post,i(size) j(brand)

label def size 1 "<150g" 2 "150g-300g" 3 "300g+"
lab val size size

rename price_pre1  Pringles_pre
rename price_post1 Pringles_post
rename price_pre2  Walker_Reg_pre
rename price_post2 Walker_Reg_post
rename price_pre6  KP_pre
rename price_post6 KP_post

order size Pringles_pre Pringles_post Walker_Reg_pre Walker_Reg_post KP_pre KP_post

sa "$Out/fi_simprice.dta",replace

*******************
***FOOD ON THE GO
*******************

insheet using "$In_out/fotgsimulations.raw",clear

rename v1  market
rename v2  product
drop   v3
rename v4  costs
rename v5  price_pre
rename v6  price_post
rename v7  share_pre
rename v8  share_post_nr
rename v9  share_post_r
drop v10
drop v11

lab var market        "Index of market"
lab var product       "Product"
lab var costs         "Imputed marginal cost"
lab var price_pre     "Price pre ban"
lab var price_post    "Price post ban (no firm response)"
lab var share_pre     "Share pre ban"
lab var share_post_nr "Share post ban (no firm response)"
lab var share_post_r  "Share post ban (firm response)"

lab val product prod_out

gen     brand = 2  if product==1|product==2
replace brand = 3  if product==3
replace brand = 4  if product==4
replace brand = 5  if product==5|product==6
replace brand = 6  if product==7
replace brand = 7  if product==8|product==9
replace brand = 10 if product==10|product==11
replace brand = 11 if product==12
replace brand = 12 if product==13

foreach v in _pre _post_nr _post_r {
    gen purchase`v' = share`v'*($Outsize/12)
}

foreach v in share_pre share_post_nr share_post_r {
    replace `v' = `v'*100
}

merge m:1 brand market using "$Data/ad_flow.dta"
drop if _m==2
drop _m

rename own_flow advertising_flow

merge 1:1 market product using "$Data/fotg_sizecost.dta"
drop if _m==2
drop _m
replace size          = 0 if size==.
replace health_cost   = 0 if health_cost==.
replace vol_energy_kj = 0 if vol_energy_kj==.
replace vol_saturates = 0 if vol_saturates==.
replace vol_salt      = 0 if vol_salt==.

gen exp_pre     = price_pre *purchase_pre
gen exp_post_nr = price_pre *purchase_post_nr
gen exp_post_r  = price_post*purchase_post_r

gen q_pre     = purchase_pre    *size
gen q_post_nr = purchase_post_nr*size
gen q_post_r  = purchase_post_r *size

gen gprof_pre     = (price_pre -costs)*purchase_pre
gen gprof_post_nr = (price_pre -costs)*purchase_post_nr
gen gprof_post_r  = (price_post-costs)*purchase_post_r

gen en_pre     = purchase_pre    *vol_energy_kj
gen en_post_nr = purchase_post_nr*vol_energy_kj
gen en_post_r  = purchase_post_r *vol_energy_kj

gen sf_pre     = purchase_pre    *vol_saturates
gen sf_post_nr = purchase_post_nr*vol_saturates
gen sf_post_r  = purchase_post_r *vol_saturates

gen st_pre     = purchase_pre    *vol_salt
gen st_post_nr = purchase_post_nr*vol_salt
gen st_post_r  = purchase_post_r *vol_salt

sa "$Out/fotg_simulations.dta",replace

u "$Out/fotg_simulations.dta",clear

gen     firm = 1 if brand==1
replace firm = 2 if brand==2 | brand==3 | brand==4 | brand==5
replace firm = 3 if brand==6
replace firm = 4 if brand==7
replace firm = 5 if brand==8
replace firm = 6 if brand==9
replace firm = 7 if brand==10
drop if brand==11|brand==12

lab val firm firm

bysort brand market: replace advertising_flow = . if _n!=1

collapse (sum) advertising_flow gprof_pre gprof_post_nr gprof_post_r q_pre q_post_nr q_post_r (mean) price_pre price_post,by(firm market)

sa "$Out/fotg_firmsimulations.dta",replace

*******************
***TOGETHER
*******************

u "$Out/fi_firmsimulations.dta",clear

foreach v in gprof_pre gprof_post_nr gprof_post_r price_pre price_post q_pre q_post_nr q_post_r {
    rename `v' `v'_in
}

merge 1:1 firm market using "$Out/fotg_firmsimulations.dta"
drop _m

foreach v in gprof_pre gprof_post_nr gprof_post_r price_pre price_post q_pre q_post_nr q_post_r {
    rename `v' `v'_out
}
foreach v in gprof_pre gprof_post_nr gprof_post_r q_pre q_post_nr q_post_r {
    gen `v' = `v'_in + `v'_out
    replace `v' = `v'_in if `v'_out==.
}
rename price_post_in price_post_r_in
rename price_post_out price_post_r_out
foreach v in pre post_r  {
    gen price_`v' = (q_`v'_in/(q_`v'_in+q_`v'_out))*price_`v'_in + (q_`v'_out/(q_`v'_in+q_`v'_out))*price_`v'_out
}

replace price_pre    = price_pre_in     if price_pre==.
replace price_post_r = price_post_r_in  if price_post_r==.

gen prof_pre = gprof_pre-advertising_flow

gen d_prof_nr = gprof_post_nr-gprof_pre+advertising_flow
gen d_prof_r  = gprof_post_r -gprof_pre+advertising_flow
gen p_prof_nr = (d_prof_nr/(gprof_pre-advertising_flow))*100
gen p_prof_r  = (d_prof_r/(gprof_pre-advertising_flow))*100

gen d_q_post_nr = q_post_nr-q_pre
gen d_q_post_r  = q_post_r -q_pre
gen p_q_post_nr = (d_q_post_nr/q_pre)*100
gen p_q_post_r  = (d_q_post_r/q_pre)*100

gen d_p_post_r  = price_post_r-price_pre
gen p_p_post_r  = (d_p_post_r/price_pre)*100

collapse (mean) advertising_flow price_pre q_pre prof_pre p_q_post_nr p_prof_nr p_p_post_r p_q_post_r p_prof_r,by(firm)

xpose,clear varname

rename v1 Pringles
rename v2 Walkers
rename v3 KP
rename v4 Golden_Wonder
rename v5 Asda
rename v6 Tesco
rename v7 Other

drop if _varname=="firm"

rename _var var
gen     vr = 1 if var=="advertising_flow"
replace vr = 2 if var=="price_pre"
replace vr = 3 if var=="q_pre"
replace vr = 4 if var=="prof_pre"
replace vr = 5 if var=="p_q_post_nr"
replace vr = 6 if var=="p_prof_nr"
replace vr = 7 if var=="p_p_post_r"
replace vr = 8 if var=="p_q_post_r"
replace vr = 9 if var=="p_prof_r"

order var vr

sa "$Out/firmsimulations.dta",replace

**************************************************************************
**Welfare
**************************************************************************

*******************
***FOOD IN
*******************

insheet using "$In_in/fiwelfare.raw",clear

rename v1  hh
rename v2  cs
rename v3  group
rename v4  market
rename v5  W_p_a
rename v6  W_hat
rename v7  W_p_0
rename v8  W_p0_0
drop v9

gen weight = 1

collapse (mean) W_p_a W_hat W_p_0 W_p0_0 (sum) weight,by(group market)

lab var group        "Household type"
lab var market       "Market"
lab var weight       "Number of households"
lab var W_p_a        "W(p,a)"
lab var W_hat        "W_hat(p,a)"
lab var W_p_0        "W(p,0)"
lab var W_p0_0       "W(p0,0)"

gen deltaW_s1_tot  = W_p0_0-W_p_a
gen deltaW_s1_comp = W_p0_0-W_p_0
gen deltaW_s1_char = W_p_0-W_p_a

gen deltaW_s2_tot  = W_p0_0-W_hat
gen deltaW_s2_comp = W_p0_0-W_p_0
gen deltaW_s2_char = W_p_0-W_hat

lab var deltaW_s1_tot  "W(p0,0)-W(p,a)"
lab var deltaW_s1_comp "W(p0,0)-W(p,0)"
lab var deltaW_s1_char "W(p,0)-W(p,a)"

lab var deltaW_s2_tot  "W(p0,0)-W_hat(p,a)"
lab var deltaW_s2_comp "W(p0,0)-W(p,0)"
lab var deltaW_s2_char "W(p,0)-W_hat(p,a)"

lab val group group

keep group market weight deltaW*

sa "$Out/fi_welfare.dta",replace

*******************
***FOOD ON THE GO
*******************

insheet using "$In_out/fotgwelfare.raw",clear

rename v1  hh
rename v2  cs
rename v3  group
rename v4  market
rename v5  W_p_a
rename v6  W_hat
rename v7  W_p_0
rename v8  W_p0_0
drop v9

gen weight = 1

collapse (mean) W_p_a W_hat W_p_0 W_p0_0 (sum) weight,by(group market)

lab var group        "Household type"
lab var market       "Market"
lab var weight       "Number of households"
lab var W_p_a        "W(p,a)"
lab var W_hat        "W_hat(p,a)"
lab var W_p_0        "W(p,0)"
lab var W_p0_0       "W(p0,0)"

gen deltaW_s1_tot  = W_p0_0-W_p_a
gen deltaW_s1_comp = W_p0_0-W_p_0
gen deltaW_s1_char = W_p_0-W_p_a

gen deltaW_s2_tot  = W_p0_0-W_hat
gen deltaW_s2_comp = W_p0_0-W_p_0
gen deltaW_s2_char = W_p_0-W_hat

lab var deltaW_s1_tot  "W(p0,0)-W(p,a)"
lab var deltaW_s1_comp "W(p0,0)-W(p,0)"
lab var deltaW_s1_char "W(p,0)-W(p,a)"

lab var deltaW_s2_tot  "W(p0,0)-W_hat(p,a)"
lab var deltaW_s2_comp "W(p0,0)-W(p,0)"
lab var deltaW_s2_char "W(p,0)-W_hat(p,a)"

lab val group group

keep group market weight deltaW*

sa "$Out/fotg_welfare.dta",replace

**************************************************************************
**Aggregate results
**************************************************************************

*******************
***FOOD IN
*******************

u "$Out/fi_simulations.dta",clear

gen temp   = share_pre     if product==27|product==28
egen outshare = sum(temp),by(market)
gen h_pre     = (share_pre    /(100-outshare))*health_cost
drop temp outshare

gen temp = share_post_nr if product==27|product==28
egen outshare = sum(temp),by(market)
gen h_post_nr = (share_post_nr/(100-outshare))*health_cost
drop temp outshare

gen temp = share_post_r  if product==27|product==28
egen outshare = sum(temp),by(market)
gen h_post_r  = (share_post_r /(100-outshare))*health_cost
drop temp outshare

collapse (sum) exp_* q_* en_* sf_* st_* gprof_* h_* advertising_flow,by(market)

sa "$Out/fi_aggfirm.dta",replace

u "$Out/fi_welfare.dta",clear

keep group market weight deltaW_s1_tot deltaW_s2_tot deltaW_s1_char deltaW_s2_char

egen sum = sum(weight),by(market)

foreach n of numlist 1(1)2 {
    gen CV_s`n'_post_r  = deltaW_s`n'_tot*(weight/sum)
    gen CV_s`n'_post_nr = deltaW_s`n'_char*(weight/sum)
}

collapse (sum) CV*,by(market)

foreach n of numlist 1(1)2 {
    replace CV_s`n'_post_r  = CV_s`n'_post_r*($Insize/12)
    replace CV_s`n'_post_nr = CV_s`n'_post_nr*($Insize/12)
}

sa "$Out/fi_aggwelfare.dta",replace

*******************
***FOOD ON THE GO
*******************

u "$Out/fotg_simulations.dta",clear

gen temp = share_pre     if product==12|product==13
egen outshare = sum(temp),by(market)
gen h_pre     = (share_pre    /(100-outshare))*health_cost
drop temp outshare

gen temp = share_post_nr if product==12|product==13
egen outshare = sum(temp),by(market)
gen h_post_nr = (share_post_nr/(100-outshare))*health_cost
drop temp outshare

gen temp = share_post_r  if product==12|product==13
egen outshare = sum(temp),by(market)
gen h_post_r  = (share_post_r /(100-outshare))*health_cost
drop temp outshare

collapse (sum) exp_* q_* en_* sf_* st_* gprof_* h_* advertising_flow,by(market)

sa "$Out/fotg_aggfirm.dta",replace

u "$Out/fotg_welfare.dta",clear

keep group market weight deltaW_s1_tot deltaW_s2_tot deltaW_s1_char deltaW_s2_char

egen sum = sum(weight),by(market)

foreach n of numlist 1(1)2 {
    gen CV_s`n'_post_r  = deltaW_s`n'_tot*(weight/sum)
    gen CV_s`n'_post_nr = deltaW_s`n'_char*(weight/sum)
}

collapse (sum) CV*,by(market)

foreach n of numlist 1(1)2 {
    replace CV_s`n'_post_r  = CV_s`n'_post_r*($Outsize/12)
    replace CV_s`n'_post_nr = CV_s`n'_post_nr*($Outsize/12)
}

sa "$Out/fotg_aggwelfare.dta",replace

*******************
***TOGETHER
*******************

u "$Out/fotg_aggwelfare.dta",clear

gen i = 1
drop market
collapse (mean) *

sa "$Out/fotg_welf_app.dta",replace

u "$Out/fi_aggwelfare.dta",clear

gen i = 1
drop market
collapse (mean) *

foreach v in CV_s1_post_r CV_s1_post_nr CV_s2_post_r CV_s2_post_nr  {
    rename `v' `v'_in
}

merge 1:1 i using "$Out/fotg_welf_app.dta"
drop _m

foreach v in CV_s1_post_r CV_s1_post_nr CV_s2_post_r CV_s2_post_nr  {
    replace `v' = `v'+`v'_in
    drop `v'_in
}

sa "$Out/welf_app.dta",replace

u "$Out/fi_aggfirm.dta",clear

foreach v in exp_pre exp_post_nr exp_post_r q_pre q_post_nr q_post_r gprof_pre gprof_post_nr gprof_post_r h_pre h_post_nr h_post_r en_pre en_post_nr en_post_r sf_pre sf_post_nr sf_post_r st_pre st_post_nr st_post_r  {
    rename `v' `v'_in
}

merge 1:1 market using "$Out/fotg_aggfirm.dta"
drop _m

foreach v in _pre _post_nr _post_r {
    replace h`v' = h`v'*(q`v'/(q`v'+q`v'_in))+h`v'_in*(q`v'_in/(q`v'+q`v'_in))
    drop h`v'_in
}

foreach v in exp_pre exp_post_nr exp_post_r q_pre q_post_nr q_post_r gprof_pre gprof_post_nr gprof_post_r en_pre en_post_nr en_post_r sf_pre sf_post_nr sf_post_r st_pre st_post_nr st_post_r {
    replace `v' = `v'+`v'_in
    drop `v'_in
}

foreach v in en sf st {
    foreach r in pre post_nr post_r {
        gen `v'_int_`r' = `v'_`r'/q_`r'
    }
}

foreach r in pre post_nr post_r {
    replace en_`r' = en_`r'/1000
    replace en_int_`r' = en_int_`r'/10
}

foreach v in sf st {
    foreach r in pre post_nr post_r {
        replace `v'_`r' = `v'_`r'*1000
        replace `v'_int_`r' = `v'_int_`r'*100
    }
}

gen prof_pre     = gprof_pre-advertising_flow
gen prof_post_nr = gprof_post_nr
gen prof_post_r  = gprof_post_r

drop gprof* advertising_flow

gen i = 1
drop market

collapse (mean) *

sa "$Out/mk_agg.dta",replace

foreach v in exp_ q_ prof_ h_ en_ sf_ st_ en_int_ sf_int_ st_int_ {
    gen `v'p_pre     = .
    gen `v'p_post_nr = ((`v'post_nr-`v'pre)/`v'pre)*100
    gen `v'p_post_r  = ((`v'post_r-`v'pre)/`v'pre)*100
}

reshape long exp_ q_ prof_ h_ en_ sf_ st_ en_int_ sf_int_ st_int_ exp_p_ q_p_ prof_p_ h_p_ en_p_ sf_p_ st_p_ en_int_p_ sf_int_p_ st_int_p_,i(i) j(regime) string
drop i

xpose,clear varname

drop if _varname=="regime"
rename _var var

gen     vr = 1  if var=="exp_"
replace vr = 2  if var=="exp_p_"
replace vr = 3  if var=="q_"
replace vr = 4  if var=="q_p_"
replace vr = 5  if var=="h_"
replace vr = 6  if var=="h_p_"
replace vr = 7  if var=="prof_"
replace vr = 8  if var=="prof_p_"
replace vr = 9  if var=="en_"
replace vr = 10 if var=="en_p_"
replace vr = 11 if var=="sf_"
replace vr = 12 if var=="sf_p_"
replace vr = 13 if var=="st_"
replace vr = 14 if var=="st_p_"
replace vr = 15 if var=="en_int_"
replace vr = 16 if var=="en_int_p_"
replace vr = 17 if var=="sf_int_"
replace vr = 18 if var=="sf_int_p_"
replace vr = 19 if var=="st_int_"
replace vr = 20 if var=="st_int_p_"

rename v1 post_nr
rename v2 post_r
rename v3 pre

sort vr

order var vr pre post_nr post_r

sa "$Out/aggregate_results.dta",replace

u "$Out/mk_agg.dta",clear

drop exp* q* h* en* sf* st*

merge 1:1 i using "$Out/welf_app.dta"
drop i _m

gen dprof_s1_post_nr = prof_post_nr-prof_pre
gen dprof_s1_post_r  = prof_post_r-prof_pre

gen dprof_s2_post_nr = dprof_s1_post_nr
gen dprof_s2_post_r  = dprof_s1_post_r

foreach n of numlist 1(1)2 {

    gen wel_s`n'_post_nr = CV_s`n'_post_nr+(prof_post_nr-prof_pre)
    gen wel_s`n'_post_r  = CV_s`n'_post_r+(prof_post_r-prof_pre)

    gen comp_s`n'_post_nr = 0
    gen comp_s`n'_post_r =  CV_s`n'_post_r-CV_s`n'_post_nr

    rename CV_s`n'_post_nr char_s`n'_post_nr
    gen    char_s`n'_post_r = char_s`n'_post_nr

    gen    tot_s`n'_post_nr = char_s`n'_post_nr
    rename CV_s`n'_post_r tot_s`n'_post_r
}

drop prof*

gen i = 1
reshape long dprof_s1_ dprof_s2_ tot_s1_ tot_s2_ char_s1_ char_s2_ comp_s1_ comp_s2_ wel_s1_ wel_s2_ ,i(i) j(regime) string
drop i

xpose,clear varname

drop if _varname=="regime"
rename _var var

gen     vr = 1  if var=="char_s1_"
replace vr = 2  if var=="comp_s1_"
replace vr = 3  if var=="tot_s1_"
replace vr = 4  if var=="dprof_s1_"
replace vr = 5  if var=="wel_s1_"
replace vr = 6  if var=="char_s2_"
replace vr = 7  if var=="comp_s2_"
replace vr = 8  if var=="tot_s2_"
replace vr = 9  if var=="dprof_s2_"
replace vr = 10 if var=="wel_s2_"

rename v1 post_nr
rename v2 post_r

sort vr

order var vr post_nr post_r

sa "$Out/aggregate_welfare_results.dta",replace

insheet using "$In_in/fisimulations.raw",clear

rename v1  market
rename v2  product
drop   v3
rename v4  costs
rename v5  price_pre
rename v6  price_post
rename v7  share_pre
rename v8  share_post_nr
rename v9  share_post_r
drop v10
drop v11

lab var market        "Index of market"
lab var product       "Product"
lab var costs         "Imputed marginal cost"
lab var price_pre     "Price pre ban"
lab var price_post    "Price post ban (no firm response)"
lab var share_pre     "Share pre ban"
lab var share_post_nr "Share post ban (no firm response)"
lab var share_post_r  "Share post ban (firm response)"

lab val product prod_in

foreach v in share_pre share_post_nr share_post_r {
    replace `v' = `v'*($Insize/($Insize+$Outsize))
}

merge 1:1 market product using "$Data/fi_sizecost.dta",keepusing(size)
drop if _m==2
drop _m

replace size = 0 if size==.

replace product = 199 if product==27
replace product = 999 if product==28

sa "$Out/fi_simshares.dta",replace

insheet using "$In_out/fotgsimulations.raw",clear

rename v1  market
rename v2  product
drop   v3
rename v4  costs
rename v5  price_pre
rename v6  price_post
rename v7  share_pre
rename v8  share_post_nr
rename v9  share_post_r
drop v10
drop v11

lab var market        "Index of market"
lab var product       "Product"
lab var costs         "Imputed marginal cost"
lab var price_pre     "Price pre ban"
lab var price_post    "Price post ban (no firm response)"
lab var share_pre     "Share pre ban"
lab var share_post_nr "Share post ban (no firm response)"
lab var share_post_r  "Share post ban (firm response)"

lab val product prod_out

foreach v in share_pre share_post_nr share_post_r {
    replace `v' = `v'*($Outsize/($Insize+$Outsize))

}

merge 1:1 market product using "$Data/fotg_sizecost.dta",keepusing(size)
drop if _m==2
drop _m

replace size = 0 if size==.

replace product = 101 if product==1
replace product = 102 if product==2
replace product = 103 if product==3
replace product = 104 if product==4
replace product = 105 if product==5
replace product = 106 if product==6
replace product = 107 if product==7
replace product = 108 if product==8
replace product = 109 if product==9
replace product = 110 if product==10
replace product = 111 if product==11
replace product = 199 if product==12
replace product = 999 if product==13

append using "$Out/fi_simshares.dta"

collapse (sum) share_pre share_post_nr share_post_r size,by(product market)

foreach v in pre post_nr post_r {
    gen temp = share_`v'
    replace temp = 0 if product==199|product==999
    egen inside_`v' = sum(temp),by(market)
    gen reshare_`v' = (share_`v'/inside_`v')
    replace reshare_`v' = 0 if product==199|product==999
    gen size_`v' = size*reshare_`v'
    drop temp
}

foreach v in pre post_nr post_r {
    gen zout1_`v' = share_`v' if product==199
    gen zout2_`v' = share_`v' if product==999
}

collapse (sum) size_pre size_post_nr size_post_r (mean) inside_pre inside_post_nr inside_post_r zout1_pre zout1_post_nr zout1_post_r zout2_pre zout2_post_nr zout2_post_r,by(market)

collapse (mean) size_pre size_post_nr size_post_r inside_pre inside_post_nr inside_post_r zout1_pre zout1_post_nr zout1_post_r zout2_pre zout2_post_nr zout2_post_r

foreach v in size_  {
    gen `v'p_pre     = .
    gen `v'p_post_nr = ((`v'post_nr-`v'pre)/`v'pre)*100
    gen `v'p_post_r  = ((`v'post_r-`v'pre)/`v'pre)*100
}

foreach v in inside_ zout1_ zout2_ {
    gen `v'p_pre     = .
    gen `v'p_post_nr = (`v'post_nr-`v'pre)*100
    gen `v'p_post_r  = (`v'post_r-`v'pre)*100
}

gen i = 1
reshape long size_ inside_ size_p_ inside_p_ zout1_ zout2_ zout1_p_ zout2_p_,i(i) j(regime) string
drop i

xpose,clear varname

drop if _varname=="regime"
rename _var var

gen     vr = 21 if var=="inside_"
replace vr = 22 if var=="inside_p_"
replace vr = 23 if var=="size_"
replace vr = 24 if var=="size_p_"
replace vr = 25 if var=="zout1_"
replace vr = 26 if var=="zout1_p_"
replace vr = 27 if var=="zout2_"
replace vr = 28 if var=="zout2_p_"

rename v3 pre
rename v1 post_nr
rename v2 post_r

sort vr

order var vr pre post_nr post_r

foreach v in pre post_nr post_r {
    replace `v'=`v'*100  if vr==21|vr==25|vr==27
    replace `v'=`v'*1000 if vr==23
}

sa "$Out/aggregate_insidesize.dta",replace
