clear
set obs 2
gen     brand = 8 if _n==1
replace brand = 9 if _n==2
gen year  = 2009
gen month = 6
gen expenditure = 0
sa "$Data/ad_temp.dta",replace

u "$DataA/RGadverts_detail.dta",clear

drop brand
rename agg_brand brand
drop if year==2009 & month<6
drop if year==2010 & month>10

collapse (sum) exp,by(year month brand)

append using "$Data/ad_temp.dta"

egen market = group(year month)

fillin brand market
drop _f
replace exp = 0 if exp==.
foreach v in month year {
    egen min = min(`v'),by(market)
    replace `v' = min if `v'==.
    drop min
}
rename exp own_flow

replace own_flow = own_flow/1000000
lab var own_flow "Advertising in m"

sa "$Data/ad_flow.dta",replace

u "$Data\week.dta",clear

collapse (mean) month year,by(week)

sa "$Data/wmy.dta",replace

u "$Data/FoodIn_characteristics.dta",clear
label drop _all

merge m:1 week using "$Data/wmy.dta"

egen market = group(year month)

gen salt = sodium/0.4

collapse (mean) size health_cost energy_kj saturates salt,by(market product)

order market product size health_cost energy_kj saturates salt

**kj
gen vol_energy_kj = energy_kj*size*10
**Kg
gen vol_saturates = (saturates*size)/100
gen vol_salt      = salt*size/100

sa "$Data/fi_sizecost.dta",replace

u "$Data/FOTG_characteristics.dta",clear
label drop _all

merge m:1 week using "$Data/wmy.dta"

egen market = group(year month)

gen salt = sodium/0.4

collapse (mean) size health_cost energy_kj saturates salt,by(market product)

order market product size health_cost energy_kj saturates salt

**kj
gen vol_energy_kj = energy_kj*size*10
**Kg
gen vol_saturates = (saturates*size)/100
gen vol_salt      = salt*size/100

replace product=1  if product==101
replace product=2  if product==102
replace product=3  if product==103
replace product=4  if product==104
replace product=5  if product==105
replace product=6  if product==106
replace product=7  if product==107
replace product=8  if product==108
replace product=9  if product==109
replace product=10 if product==110
replace product=11 if product==111

sa "$Data/fotg_sizecost.dta",replace


foreach v in FoodIn FOTG {

    u "$Data/`v'_brand_nutrients.dta",clear

    gen     energy_score = 0  if energy_kj<=335
    replace energy_score = 1  if energy_kj>335  &energy_kj<=670
    replace energy_score = 2  if energy_kj>670  &energy_kj<=1005
    replace energy_score = 3  if energy_kj>1005 &energy_kj<=1340
    replace energy_score = 4  if energy_kj>1340 &energy_kj<=1675
    replace energy_score = 5  if energy_kj>1675 &energy_kj<=2010
    replace energy_score = 6  if energy_kj>2010 &energy_kj<=2345
    replace energy_score = 7  if energy_kj>2345 &energy_kj<=2680
    replace energy_score = 8  if energy_kj>2680 &energy_kj<=3015
    replace energy_score = 9  if energy_kj>3015 &energy_kj<=3350
    replace energy_score = 10 if energy_kj>3350 &energy_kj!=.

    gen     sat_score = 0  if saturates<=1
    replace sat_score = 1  if saturates>1  &saturates<=2
    replace sat_score = 2  if saturates>2  &saturates<=3
    replace sat_score = 3  if saturates>3  &saturates<=4
    replace sat_score = 4  if saturates>4  &saturates<=5
    replace sat_score = 5  if saturates>5  &saturates<=6
    replace sat_score = 6  if saturates>6  &saturates<=7
    replace sat_score = 7  if saturates>7  &saturates<=8
    replace sat_score = 8  if saturates>8  &saturates<=9
    replace sat_score = 9  if saturates>9  &saturates<=10
    replace sat_score = 10 if saturates>10 &saturates!=.

    gen     sug_score = 0  if sugars<=4.5
    replace sug_score = 1  if sugars>4.5  &sugars<=9
    replace sug_score = 2  if sugars>9    &sugars<=13.5
    replace sug_score = 3  if sugars>13.5 &sugars<=18
    replace sug_score = 4  if sugars>18   &sugars<=22.5
    replace sug_score = 5  if sugars>22.5 &sugars<=27
    replace sug_score = 6  if sugars>27   &sugars<=31
    replace sug_score = 7  if sugars>31   &sugars<=36
    replace sug_score = 8  if sugars>36   &sugars<=40
    replace sug_score = 9  if sugars>40   &sugars<=45
    replace sug_score = 10 if sugars>45   &sugars!=.

    gen     sod_score = 0  if sodium<=0.09
    replace sod_score = 1  if sodium>0.09 &sodium<=0.18
    replace sod_score = 2  if sodium>0.18 &sodium<=0.27
    replace sod_score = 3  if sodium>0.27 &sodium<=0.36
    replace sod_score = 4  if sodium>0.36 &sodium<=0.45
    replace sod_score = 5  if sodium>0.45 &sodium<=0.54
    replace sod_score = 6  if sodium>0.54 &sodium<=0.63
    replace sod_score = 7  if sodium>0.63 &sodium<=0.72
    replace sod_score = 8  if sodium>0.72 &sodium<=0.81
    replace sod_score = 9  if sodium>0.81 &sodium<=0.9
    replace sod_score = 10 if sodium>0.9  &sodium!=.

    ***Based on AOAC scale
    gen     fruit_score = 0
    *replace fruit_score = 5 if totalfotgmarket=="Fruit Salad"|totalfotgmarket=="Nuts Fruit+Nut Mixtures"

    gen     fib_score = 0  if fibre<=0.9
    replace fib_score = 1  if fibre>0.9 &fibre<=1.9
    replace fib_score = 2  if fibre>1.9 &fibre<=2.8
    replace fib_score = 3  if fibre>2.8 &fibre<=3.7
    replace fib_score = 4  if fibre>3.7 &fibre<=4.7
    replace fib_score = 5  if fibre>4.7 &fibre!=.

    gen     prot_score = 0  if protein<=1.6
    replace prot_score = 1  if protein>1.6 &protein<=3.2
    replace prot_score = 2  if protein>3.2 &protein<=4.8
    replace prot_score = 3  if protein>4.8 &protein<=6.4
    replace prot_score = 4  if protein>6.4 &protein<=8.0
    replace prot_score = 5  if protein>8.0 &protein!=.

    gen A_score = energy_score+sat_score+sug_score+sod_score

    gen health_cost = 0
    replace health_cost = A_score - fruit_score - fib_score - prot_score if A_score<11
    replace health_cost = A_score - fruit_score - fib_score - prot_score if A_score>=11 & fruit_score==5
    replace health_cost = A_score - fruit_score - fib_score              if A_score>=11 & fruit_score<5

    gen salt = sodium/0.4

    keep agg_brand health_cost saturates salt

    rename agg_brand brand

    sa "$Data/health_cost_`v'.dta",replace
}

u "$Data/FoodIn_Computations_group1.dta",clear

gen R = 1
foreach n of numlist 2(1)11 {
    append using "$Data/FoodIn_Computations_group`n'.dta"
    replace R = `n' if R==.
}
keep if agg_brand==2

collapse (min) p0=own_stock (p10) p10=own_stock (p50) p50=own_stock (p90) p90=own_stock (max) p100=own_stock

foreach v in p0 p10 p50 p90 p100 {
    replace `v' = ln(`v'+(`v'^2+1)^(0.5))
}

sa "$Data/ad_for_wtp.dta",replace
